@@ -1,4 +1,5 @@
 import os
+import json
 from redis import Redis
 from redis.exceptions import ConnectionError
 from cvai_logger import hlogger
@@ -8,6 +9,8 @@ CACHING_PORT = 6379
 LOCALHOST_CACHING_HOST = 'localhost'
 CACHING_HOST = os.getenv('CACHING_HOST', LOCALHOST_CACHING_HOST)
 
+DEFAULT_EXP_TIME = 2 * 60 # 2 minutes
+
 redis_client = Redis(host=CACHING_HOST, port=CACHING_PORT)
 
 def safe_cache(func):
@@ -21,8 +24,12 @@ def safe_cache(func):
     return inner
 
 @safe_cache
-def set_cache(key, value):
-    return redis_client.set(key, value)
+def set_cache(key, value, exp=DEFAULT_EXP_TIME):
+    if type(value) == dict:
+        value = json.dumps(value)
+    res = redis_client.set(key, value, ex=exp)
+    redis_client.expire(key, exp)
+    return res
 
 @safe_cache
 def get_cache(key):
